<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">工程管理统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="search">
            <el-date-picker
                v-model="year"
                type="year"
                placeholder="请选择年限"
                value-format="yyyy"
                format="yyyy"
                style="margin-right: 10px"
            >
            </el-date-picker>
            <el-button size="small" @click="findinfo" type="primary">查询</el-button>
            <el-button size="small" @click="reset" type="plain"> 重置 </el-button>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column align="center" prop="name" label="名称">
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="projectMoney"
                    label="年度预算金额(万元)"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.projectMoney) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="contractMoney"
                    label="合同预算金额(万元)"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.contractMoney) }}
                    </template></el-table-column
                >
                <el-table-column align="center" prop="progress" label="工程进度" />
                <el-table-column align="center" prop="payMoney" label="计量支付（万元）">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.payMoney) }}
                    </template>
                </el-table-column>
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span class="item">{{ total.projectMoney || 0 }}</span>
                <span class="item">{{ total.contractMoney || 0 }}</span>
                <span class="item">{{ total.progress || 0 }}</span>
                <span class="item">{{ total.payMoney || 0 }}</span>
            </div>
        </div>
        <div class="charts">
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon clumn-icon"></i>
                    <!-- 各总部工程预算金额统计 -->
                    <span class="charts_title-text">预算金额统计</span>
                </div>
                <div id="column" style="height: 100%; width: 100%"></div>
            </div>
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon"></i>
                    <!-- 年度预算金额统计 -->
                    <span class="charts_title-text">年度预算金额</span>
                </div>
                <div id="pie" style="height: 100%; width: 100%"></div>
            </div>
        </div>
    </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
import * as echarts from 'echarts'
export default {
    name: 'specialProjectManagement',
    data() {
        return {
            tableData: [],
            data: [],
            loading: false,
            year: new Date(),
            total: {},
            utils: utils,
        }
    },
    created() {
        this.loadData()
    },
    watch: {
        tableData(newVal) {
            this.total.projectMoney = this.calculation('projectMoney', newVal)
            this.total.contractMoney = this.calculation('contractMoney', newVal)
            this.total.progress = this.calculation('progress', newVal) + '%'
            this.total.payMoney = this.calculation('payMoney', newVal)
            this.cloumnCharts(newVal)
            this.pieCharts(newVal)
        },
    },
    methods: {
        reset() {
            this.year = ''
            this.loadData()
        },
        calculation(key, arr) {
            let total = new BigNumber(0)
            if (!key || arr.length === 0) return total.toFixed(2)
            arr.forEach((item) => {
                if (key == 'progress') {
                    total = total.plus(item[key].split('%')[0])
                } else {
                    total = total.plus(item[key])
                }
            })
            if (key == 'progress') {
                let num = this.tableData.length || 1
                total = total.div(num)
            }
            if (total === 0) return 0.0
            return utils.thousandBit(total.toFixed(2))
        },
        changeYear(val) {
            if (!val) {
                return this.loadData()
            }
            this.loading = true
            this.$http
                .post('${yhxt}/bizEngineeringProject/v1/getProjectCountVo?year=' + val)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        findinfo() {
            let val = this.year
            this.loading = true
            this.$http
                .post('${yhxt}/bizEngineeringProject/v1/getProjectCountVo?year=' + val)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (typeof this.year == 'object') {
                this.year = this.year.getFullYear()
            }
            if (row.chirldren.length == 0 && row.roadSegmentId) {
                return this.$router.push({
                    name: 'projectManagementChildren',
                    params: {
                        value: row,
                        year: this.year,
                    },
                })
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            // this.cstatus = column.label
        },
        loadData() {
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/bizEngineeringProject/v1/getProjectCountVo?year=' +
                        new Date().getFullYear()
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        cloumnCharts(data) {
            var chartDom = document.getElementById('column')
            var myChart = echarts.init(chartDom)
            let source = []
            let obj = {
                run: '年度预算金额',
                finish: '合同预算金额',
                temporary: '计量支付',
            }
            data.forEach((item) => {
                source.push({
                    product: item.name,
                    [obj.run]: item.projectMoney,
                    [obj.finish]: item.contractMoney,
                    [obj.temporary]: item.payMoney,
                })
            })
            var option
            option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                grid: {
                    top: '20%',
                    left: '10%',
                    right: '10%',
                    bottom: '20%',
                },
                legend: {
                    itemHeight: 10,
                    itemWidth: 10,
                    bottom: 'bottom',
                    bottom: '8%',
                    textStyle: {
                        color: '#fff',
                    },
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'none',
                    },
                },
                color: [
                    '#68c1e5',
                    '#56d0a3',
                    '#16ffae',
                    '#00e6f6',
                    '#578bf1',
                    '#6255f8',
                    '#0282b9',
                    '#596d90',
                    '#6a5cf1',
                ],
                dataset: {
                    dimensions: ['product', '年度预算金额', '合同预算金额', '计量支付'],
                    source: source,
                },
                xAxis: {
                    type: 'category',
                    axisLabel: {
                        fontSize: 14,
                        color: '#B8C2CC',
                    },
                    axisTick: {
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                yAxis: {
                    name: '单位：万元',
                    nameTextStyle: {
                        color: '#B8C2CC',
                        nameLocation: 'start',
                        fontSize: 18,
                        fontWeight: 700,
                    },
                    type: 'value',
                    splitLine: {show: false}, //去除网格线
                    axisLabel: {
                        textStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                series: [
                    {
                        type: 'bar',
                        itemStyle: {
                            color: '#578af0',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        type: 'bar',
                        itemStyle: {
                            color: '#56cfa2',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        type: 'bar',
                        itemStyle: {
                            color: '#56cfa2',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
        pieCharts(data) {
            var chartDom = document.getElementById('pie')
            var myChart = echarts.init(chartDom)
            let data_ = []
            data.forEach((item) => {
                data_.push({
                    name: item.name,
                    value: item.projectMoney || 0,
                })
            })
            var option

            let total = this.calculation('projectMoney', data)
            let formatNumber = (num) => num.toString().replace(/(?=(\B)(\d{3})+$)/g, ',')
            option = {
                title: [
                    {
                        text: `{name|年度预算金额统计/万元}\n{val|${formatNumber(
                            total
                        )}}`,
                        top: 'center',
                        left: 'center',
                        textStyle: {
                            rich: {
                                name: {
                                    fontSize: 14,
                                    color: '#fff',
                                    padding: [10, 0],
                                },
                                val: {
                                    fontSize: 32,
                                    fontWeight: 'bold',
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
                tooltip: {
                    trigger: 'item',
                    formatter: (a) => {
                        return `${a.marker} ${a.data.name} ${a.data.value}万元 ${a.percent}%`
                    },
                },
                color: [
                    '#578bf1',
                    '#6255f8',
                    '#68c1e5',
                    '#56d0a3',
                    '#16ffae',
                    '#00e6f6',
                    '#0282b9',
                    '#596d90',
                    '#6a5cf1',
                ],
                legend: {
                    icon: 'circle',
                    orient: 'vertical',
                    right: 70,
                    top: 'center',
                    bottom: 20,
                    textStyle: {
                        color: '#ccc',
                    },
                },
                series: [
                    {
                        type: 'pie',
                        radius: ['40%', '60%'],
                        // center: ['45%', '50%'],
                        data: data_,
                        label: {
                            alignTo: 'edge',
                            formatter: (a) => {
                                return `{percent|${a.percent}%}`
                            },
                            minMargin: 5,
                            edgeDistance: 80,
                            rich: {
                                percent: {
                                    fontSize: 15,
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;
    overflow: auto;
    box-sizing: border-box;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .search {
        margin-top: 32px;
    }
    .table {
        margin-top: 12px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:not(:nth-child(1)) {
                    flex: 1;
                }
            }
        }
    }
    .charts {
        margin-top: 32px;
        display: flex;
        .charts-border {
            position: relative;
            height: 507px;
            flex: 1;
            background-size: 100% 100%;
            background-image: url('../../assets/img/框@2x.png');
            .charts_title {
                display: flex;
                height: 24px;
                align-items: center;
                position: absolute;
                top: 30px;
                left: 25px;
            }
            .charts_title-icon {
                display: block;
                width: 20px;
                height: 20px;
                background-size: 100% 100%;
                background-image: url('../../assets/img/icon-饼图@2x.png');
            }
            .clumn-icon {
                background-image: url('../../assets/img/icon-柱图@2x.png');
            }
            .charts_title-text {
                margin-left: 5px;
                height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 24px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
    }
}
</style>
